@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -19,9 +19,8 @@ import json
 import logging
 import queue
 import typing
-from collections import defaultdict, namedtuple
+from collections import defaultdict
 from collections.abc import Callable
-from statistics import mean, median
 from types import (
     BuiltinFunctionType,
     FunctionType,
@@ -30,10 +29,11 @@ from types import (
     ModuleType,
     WrapperDescriptorType,
 )
-from typing import Any, NamedTuple
+from typing import Any
 
 import astroid
 
+import pynguin.utils.statistics.statistics as stat
 import pynguin.utils.typetracing as tt
 from pynguin.analyses.modulecomplexity import mccabe_complexity
 from pynguin.analyses.syntaxtree import (
@@ -43,6 +43,11 @@ from pynguin.analyses.syntaxtree import (
     get_function_description,
     get_function_node_from_ast,
 )
+from pynguin.analyses.type4py_api import (
+    Type4pyData,
+    find_predicted_signature,
+    query_type4py_api,
+)
 from pynguin.analyses.typesystem import (
     ANY,
     AnyType,
@@ -54,6 +59,7 @@ from pynguin.analyses.typesystem import (
     TypeSystem,
     TypeVisitor,
     UnionType,
+    Unsupported,
     is_primitive_type,
 )
 from pynguin.configuration import TypeInferenceStrategy
@@ -79,7 +85,7 @@ from pynguin.utils.type_utils import (
 if typing.TYPE_CHECKING:
     import pynguin.ga.computations as ff
     import pynguin.generation.algorithms.archive as arch
-    from pynguin.testcase.execution import KnownData
+    from pynguin.testcase.execution import SubjectProperties
 
 AstroidFunctionDef: typing.TypeAlias = astroid.AsyncFunctionDef | astroid.FunctionDef
 
@@ -176,6 +182,9 @@ MODULE_BLACKLIST = frozenset(
     )
 )
 
+# Blacklist for methods.
+METHOD_BLACKLIST = frozenset(("time.sleep",))
+
 
 def _is_blacklisted(element: Any) -> bool:
     """Checks if the given element belongs to the blacklist.
@@ -198,26 +207,32 @@ def _is_blacklisted(element: Any) -> bool:
     if inspect.isfunction(element):
         # Some modules can be run standalone using a main function or provide a small
         # set of tests ('test'). We don't want to include those functions.
-        return element.__module__ in MODULE_BLACKLIST or element.__name__ in (
-            "main",
-            "test",
+        return (
+            element.__module__ in MODULE_BLACKLIST
+            or element.__qualname__.startswith(
+                (
+                    "main",
+                    "test",
+                )
+            )
+            or f"{element.__module__}.{element.__qualname__}" in METHOD_BLACKLIST
         )
     # Something that is not supported yet.
     return False
 
 
-class _ModuleParseResult(NamedTuple):
+@dataclasses.dataclass
+class _ModuleParseResult:
     """A data wrapper for an imported and parsed module."""
 
     linenos: int
     module_name: str
     module: ModuleType
     syntax_tree: astroid.Module | None
+    type4py_data: Type4pyData | None
 
 
-def parse_module(
-    module_name: str,
-) -> _ModuleParseResult:
+def parse_module(module_name: str, query_type4py: bool = False) -> _ModuleParseResult:
     """Parses a module and extracts its module-type and AST.
 
     If the source code is not available it is not possible to build an AST.  In this
@@ -227,12 +242,15 @@ def parse_module(
 
     Args:
         module_name: The fully-qualified name of the module
+        query_type4py: Query the configured type4py service for the given module.
 
     Returns:
         A tuple of the imported module type and its optional AST
     """
     module = importlib.import_module(module_name)
-
+    type4py_data: Type4pyData | None = None
+    syntax_tree: astroid.Module | None = None
+    linenos: int = -1
     try:
         source_file = inspect.getsourcefile(module)
         source_code = inspect.getsource(module)
@@ -242,20 +260,26 @@ def parse_module(
             path=source_file if source_file is not None else "",
         )
         linenos = len(source_code.splitlines())
+        if query_type4py:
+            type4py_data = query_type4py_api(module_name, source_code)
+
     except (TypeError, OSError) as error:
         LOGGER.debug(
             f"Could not retrieve source code for module {module_name} ({error}). "
             f"Cannot derive syntax tree to allow Pynguin using more precise analysis."
         )
-        syntax_tree = None
-        linenos = -1
+
     return _ModuleParseResult(
-        linenos=linenos, module_name=module_name, module=module, syntax_tree=syntax_tree
+        linenos=linenos,
+        module_name=module_name,
+        module=module,
+        syntax_tree=syntax_tree,
+        type4py_data=type4py_data,
     )
 
 
 class TestCluster(abc.ABC):
-    """Interface for a test cluster"""
+    """Interface for a test cluster."""
 
     @property
     @abc.abstractmethod
@@ -268,7 +292,7 @@ class TestCluster(abc.ABC):
         """Provide the number of source code lines."""
 
     @abc.abstractmethod
-    def log_signatures(self) -> None:
+    def log_cluster_statistics(self) -> None:
         """Log the signatures of all seen callables."""
 
     @abc.abstractmethod
@@ -318,7 +342,8 @@ class TestCluster(abc.ABC):
     def num_accessible_objects_under_test(self) -> int:
         """Provide the number of accessible objects under test.
 
-        Useful to check whether there is even something to test."""
+        Useful to check whether there is even something to test.
+        """
 
     @abc.abstractmethod
     def get_generators_for(
@@ -429,7 +454,7 @@ class TestCluster(abc.ABC):
         self,
         accessible: GenericCallableAccessibleObject,
         param_name: str,
-        knowledge: tt.ProxyKnowledge,
+        knowledge: tt.UsageTraceNode,
     ) -> None:
         """Update the knowledge about the parameter of the given accessible.
 
@@ -440,6 +465,56 @@ class TestCluster(abc.ABC):
         """
 
 
+@dataclasses.dataclass
+class SignatureInfo:
+    """Another utility class to group information per callable."""
+
+    # A dictionary mapping parameter names and to their developer annotated parameters
+    # types.
+    # Does not include self, etc.
+    annotated_parameter_types: dict[str, str] = dataclasses.field(default_factory=dict)
+
+    # Similar to above, but with guessed parameters types.
+    # Contains multiples type guesses.
+    guessed_parameter_types: dict[str, list[str]] = dataclasses.field(
+        default_factory=dict
+    )
+
+    # Similar to above, but retrieved from Type4Py.
+    type4py_parameter_types: dict[str, list[str]] = dataclasses.field(
+        default_factory=dict
+    )
+
+    # Needed to compute top-n accuracy in the evaluation.
+    # Elements are of form (A,B); A is a guess, B is an annotated type.
+    # (A,B) is only present, when A is a base type match of B.
+    # If it is present, it points to the partial type match between A and B.
+    partial_type_matches: dict[str, str] = dataclasses.field(default_factory=dict)
+
+    # Annotated return type, if Any.
+    # Does not include constructors.
+    annotated_return_type: str | None = None
+
+    # Recorded return type, if Any.
+    recorded_return_types: list[str] = dataclasses.field(default_factory=list)
+
+    # Type4Py return type
+    type4py_return_types: list[str] = dataclasses.field(default_factory=list)
+
+
+@dataclasses.dataclass
+class TypeGuessingStats:
+    """Class to gather some type guessing related statistics."""
+
+    # Number of constructors in the MUT.
+    number_of_constructors: int = 0
+
+    # Maps names of callables to a signature info object.
+    signature_infos: dict[str, SignatureInfo] = dataclasses.field(
+        default_factory=lambda: defaultdict(SignatureInfo)
+    )
+
+
 class ModuleTestCluster(TestCluster):
     """A test cluster for a module.
 
@@ -469,9 +544,40 @@ class ModuleTestCluster(TestCluster):
         # Keep track of all callables, this is only for statistics purposes.
         self.__callables: OrderedSet[GenericCallableAccessibleObject] = OrderedSet()
 
-    def log_signatures(self) -> None:
-        for call in self.__callables:
-            LOGGER.debug("%s", call)
+    def log_cluster_statistics(self) -> None:
+        stats = TypeGuessingStats()
+        for accessible in self.__accessible_objects_under_test:
+            if isinstance(accessible, GenericCallableAccessibleObject):
+                accessible.inferred_signature.log_stats_and_guess_signature(
+                    accessible.is_constructor(), str(accessible), stats
+                )
+
+        def _serialize_helper(obj):
+            """Utility to deal with non-serializable types.
+
+            Args:
+                obj: The object to serialize
+
+            Returns:
+                A serializable object.
+            """
+            if isinstance(obj, set):
+                return list(obj)
+            if isinstance(obj, SignatureInfo):
+                return dataclasses.asdict(obj)
+            return obj
+
+        stat.track_output_variable(
+            RuntimeVariable.SignatureInfos,
+            json.dumps(
+                stats.signature_infos,
+                default=_serialize_helper,
+            ),
+        )
+        stat.track_output_variable(
+            RuntimeVariable.NumberOfConstructors,
+            str(stats.number_of_constructors),
+        )
 
     def _drop_generator(self, accessible: GenericCallableAccessibleObject):
         gens = self.__generators.get(accessible.generated_type())
@@ -490,20 +596,18 @@ class ModuleTestCluster(TestCluster):
             items = old_type.items
             if len(items) >= max_size or new_type in items:
                 return old_type
-            new_type = UnionType(old_type.items + (new_type,))
+            new_type = UnionType(tuple(sorted(items + (new_type,))))
         else:
             if old_type in (ANY, new_type):
                 new_type = UnionType((new_type,))
             else:
-                new_type = UnionType((old_type, new_type))
+                new_type = UnionType(tuple(sorted((old_type, new_type))))
         return new_type
 
     def update_return_type(
         self, accessible: GenericCallableAccessibleObject, new_type: ProperType
     ) -> None:
         # Loosely map runtime type to proper type
-        # TODO(fk) what about tuple?
-        #  Think about updates, only Any?
         old_type = accessible.inferred_signature.return_type
 
         new_type = self._add_or_make_union(old_type, new_type)
@@ -522,10 +626,10 @@ class ModuleTestCluster(TestCluster):
         self,
         accessible: GenericCallableAccessibleObject,
         param_name: str,
-        knowledge: tt.ProxyKnowledge,
+        knowledge: tt.UsageTraceNode,
     ) -> None:
         # Store new data
-        accessible.inferred_signature.knowledge[param_name].merge(knowledge)
+        accessible.inferred_signature.usage_trace[param_name].merge(knowledge)
 
     @property
     def type_system(self) -> TypeSystem:
@@ -631,9 +735,14 @@ class ModuleTestCluster(TestCluster):
         ) -> OrderedSet[GenericAccessibleObject]:
             result: OrderedSet[GenericAccessibleObject] = OrderedSet()
             for element in left.items:
-                result.update(element.accept(self))
+                result.update(element.accept(self))  # type:ignore
             return result
 
+        def visit_unsupported_type(
+            self, left: Unsupported
+        ) -> OrderedSet[GenericAccessibleObject]:
+            raise NotImplementedError("This type shall not be used during runtime")
+
     def get_modifiers_for(self, typ: ProperType) -> OrderedSet[GenericAccessibleObject]:
         return typ.accept(self._FindModifiers(self))
 
@@ -656,7 +765,7 @@ class ModuleTestCluster(TestCluster):
             raise ConstructionFailedException(f"No modifiers for {typ}")
         return randomness.choice(accessible_objects)
 
-    @functools.lru_cache()
+    @functools.lru_cache(maxsize=128)
     def get_all_generatable_types(self) -> list[ProperType]:
         generatable = OrderedSet(self.__generators.keys())
         generatable.update(self.type_system.primitive_proper_types)
@@ -681,39 +790,26 @@ class ModuleTestCluster(TestCluster):
             RuntimeVariable.GeneratableTypes, len(self.get_all_generatable_types())
         )
 
-        cyclomatic_complexity = self.__compute_cyclomatic_complexities(
+        cyclomatic_complexities = self.__compute_cyclomatic_complexities(
             self.function_data_for_accessibles.values()
         )
-        if cyclomatic_complexity is not None:
-            tracking_fun(RuntimeVariable.McCabeMin, cyclomatic_complexity.min)
-            tracking_fun(RuntimeVariable.McCabeMean, cyclomatic_complexity.mean)
-            tracking_fun(RuntimeVariable.McCabeMedian, cyclomatic_complexity.median)
-            tracking_fun(RuntimeVariable.McCabeMax, cyclomatic_complexity.max)
+        if cyclomatic_complexities is not None:
+            tracking_fun(RuntimeVariable.McCabeAST, json.dumps(cyclomatic_complexities))
             tracking_fun(RuntimeVariable.LineNos, self.__linenos)
 
-    CyclomaticComplexity = namedtuple("CyclomaticComplexity", "min mean median max")
-
     @staticmethod
     def __compute_cyclomatic_complexities(
         callable_data: typing.Iterable[_CallableData],
-    ) -> CyclomaticComplexity | None:
+    ) -> list[int]:
         # Collect complexities only for callables that had an AST.  Their minimal
         # complexity is 1, the value None symbolises a callable that had no AST present,
         # either because there is none or because it is an implicitly added function,
         # such as a default constructor or the constructor of a base class.
-        complexities = [
+        return [
             item.cyclomatic_complexity
             for item in callable_data
             if item.cyclomatic_complexity is not None
         ]
-        if len(complexities) == 0:
-            return None
-        return ModuleTestCluster.CyclomaticComplexity(
-            min=min(complexities),
-            mean=mean(complexities),
-            median=median(complexities),
-            max=max(complexities),
-        )
 
 
 # pylint:disable=too-many-public-methods
@@ -738,7 +834,7 @@ class FilteredModuleTestCluster(TestCluster):
         self,
         accessible: GenericCallableAccessibleObject,
         param_name: str,
-        knowledge: tt.ProxyKnowledge,
+        knowledge: tt.UsageTraceNode,
     ) -> None:
         self.__delegate.update_parameter_knowledge(accessible, param_name, knowledge)
 
@@ -746,8 +842,8 @@ class FilteredModuleTestCluster(TestCluster):
     def linenos(self) -> int:
         return self.__delegate.linenos
 
-    def log_signatures(self) -> None:
-        self.__delegate.log_signatures()
+    def log_cluster_statistics(self) -> None:
+        self.__delegate.log_cluster_statistics()
 
     def add_generator(self, generator: GenericAccessibleObject) -> None:
         self.__delegate.add_generator(generator)
@@ -775,17 +871,15 @@ class FilteredModuleTestCluster(TestCluster):
         self,
         delegate: ModuleTestCluster,
         archive: arch.Archive,
-        known_data: KnownData,
+        subject_properties: SubjectProperties,
         targets: OrderedSet[ff.TestCaseFitnessFunction],
     ) -> None:
         self.__delegate = delegate
-        self.__known_data = known_data
+        self.__subject_properties = subject_properties
         self.__code_object_id_to_accessible_objects: dict[
             int, GenericCallableAccessibleObject
         ] = {
-            json.loads(acc.callable.__code__.co_consts[0])[  # type: ignore
-                CODE_OBJECT_ID_KEY
-            ]: acc
+            json.loads(acc.callable.__code__.co_consts[0])[CODE_OBJECT_ID_KEY]: acc
             for acc in delegate.accessible_objects_under_test
             if isinstance(acc, GenericCallableAccessibleObject)
             and hasattr(acc.callable, "__code__")
@@ -818,13 +912,13 @@ class FilteredModuleTestCluster(TestCluster):
                 )
             ) is not None:
                 return acc
-            code_object_id = self.__known_data.existing_code_objects[
+            code_object_id = self.__subject_properties.existing_code_objects[
                 code_object_id
             ].parent_code_object_id
         return None
 
     def on_target_covered(self, target: ff.TestCaseFitnessFunction) -> None:
-        """A callback function to get informed by an archive when a target is covered
+        """A callback function to get informed by an archive when a target is covered.
 
         Args:
             target: The newly covered target
@@ -924,6 +1018,7 @@ def __analyse_function(
     func: FunctionType,
     type_inference_strategy: TypeInferenceStrategy,
     module_tree: astroid.Module | None,
+    type4py_data: Type4pyData | None,
     test_cluster: ModuleTestCluster,
     add_to_test: bool,
 ) -> None:
@@ -939,7 +1034,9 @@ def __analyse_function(
 
     LOGGER.debug("Analysing function %s", func_name)
     inferred_signature = test_cluster.type_system.infer_type_info(
-        func, type_inference_strategy
+        func,
+        type4py_data=find_predicted_signature(type4py_data, func_name),
+        type_inference_strategy=type_inference_strategy,
     )
     func_ast = get_function_node_from_ast(module_tree, func_name)
     description = get_function_description(func_ast)
@@ -964,6 +1061,7 @@ def __analyse_class(  # pylint: disable=too-many-arguments
     type_info: TypeInfo,
     type_inference_strategy: TypeInferenceStrategy,
     module_tree: astroid.Module | None,
+    type4py_data: Type4pyData | None,
     test_cluster: ModuleTestCluster,
     add_to_test: bool,
 ) -> None:
@@ -991,7 +1089,11 @@ def __analyse_class(  # pylint: disable=too-many-arguments
         generic = GenericConstructor(
             type_info,
             test_cluster.type_system.infer_type_info(
-                type_info.raw_type, type_inference_strategy
+                getattr(type_info.raw_type, "__init__"),
+                type4py_data=find_predicted_signature(
+                    type4py_data, type_info.qualname + ".__init__", type_info.qualname
+                ),
+                type_inference_strategy=type_inference_strategy,
             ),
             raised_exceptions,
         )
@@ -1025,6 +1127,7 @@ def __analyse_class(  # pylint: disable=too-many-arguments
             method=method,
             type_inference_strategy=type_inference_strategy,
             class_tree=class_ast,
+            type4py_data=type4py_data,
             test_cluster=test_cluster,
             add_to_test=add_to_test,
         )
@@ -1052,9 +1155,9 @@ def __add_symbols(class_ast: astroid.ClassDef | None, type_info: TypeInfo) -> No
     """
     if class_ast is not None:
         type_info.instance_attributes.update(tuple(class_ast.instance_attrs))
-    type_info.symbols.update(type_info.instance_attributes)
-    type_info.symbols.update(tuple(vars(type_info.raw_type)))
-    type_info.symbols.difference_update(IGNORED_SYMBOLS)
+    type_info.attributes.update(type_info.instance_attributes)
+    type_info.attributes.update(tuple(vars(type_info.raw_type)))
+    type_info.attributes.difference_update(IGNORED_SYMBOLS)
 
 
 def __analyse_method(  # pylint: disable=too-many-arguments
@@ -1069,6 +1172,7 @@ def __analyse_method(  # pylint: disable=too-many-arguments
     ),
     type_inference_strategy: TypeInferenceStrategy,
     class_tree: astroid.ClassDef | None,
+    type4py_data: Type4pyData | None,
     test_cluster: ModuleTestCluster,
     add_to_test: bool,
 ) -> None:
@@ -1089,7 +1193,11 @@ def __analyse_method(  # pylint: disable=too-many-arguments
 
     LOGGER.debug("Analysing method %s.%s", type_info.full_name, method_name)
     inferred_signature = test_cluster.type_system.infer_type_info(
-        method, type_inference_strategy
+        method,
+        type4py_data=find_predicted_signature(
+            type4py_data, type_info.qualname + "." + method_name, type_info.qualname
+        ),
+        type_inference_strategy=type_inference_strategy,
     )
     method_ast = get_function_node_from_ast(class_tree, method_name)
     description = get_function_description(method_ast)
@@ -1111,9 +1219,13 @@ def __analyse_method(  # pylint: disable=too-many-arguments
 
 
 class _ParseResults(dict):
+    def __init__(self, query_type4py: bool):
+        super().__init__()
+        self._query_type4py = query_type4py
+
     def __missing__(self, key):
         # Parse module on demand
-        res = self[key] = parse_module(key)
+        res = self[key] = parse_module(key, query_type4py=self._query_type4py)
         return res
 
 
@@ -1121,9 +1233,12 @@ def __resolve_dependencies(
     root_module: _ModuleParseResult,
     type_inference_strategy: TypeInferenceStrategy,
     test_cluster: ModuleTestCluster,
+    query_type4py: bool = False,
 ) -> None:
 
-    parse_results: dict[str, _ModuleParseResult] = _ParseResults()
+    parse_results: dict[str, _ModuleParseResult] = _ParseResults(
+        query_type4py=query_type4py
+    )
     parse_results[root_module.module_name] = root_module
 
     # Provide a set of seen modules, classes and functions for fixed-point iteration
@@ -1188,7 +1303,7 @@ def __resolve_dependencies(
     LOGGER.info("Functions: %5i", len(seen_functions))
     LOGGER.info("Classes:   %5i", len(seen_classes))
 
-    test_cluster.type_system.push_symbols_down()
+    test_cluster.type_system.push_attributes_down()
 
 
 def __analyse_included_classes(
@@ -1220,6 +1335,7 @@ def __analyse_included_classes(
             type_info=type_info,
             type_inference_strategy=type_inference_strategy,
             module_tree=parse_results[current.__module__].syntax_tree,
+            type4py_data=parse_results[current.__module__].type4py_data,
             test_cluster=test_cluster,
             add_to_test=current.__module__ == root_module_name,
         )
@@ -1260,6 +1376,7 @@ def __analyse_included_functions(
             func=current,
             type_inference_strategy=type_inference_strategy,
             module_tree=parse_results[current.__module__].syntax_tree,
+            type4py_data=parse_results[current.__module__].type4py_data,
             test_cluster=test_cluster,
             add_to_test=current.__module__ == root_module_name,
         )
@@ -1268,12 +1385,14 @@ def __analyse_included_functions(
 def analyse_module(
     parsed_module: _ModuleParseResult,
     type_inference_strategy: TypeInferenceStrategy = TypeInferenceStrategy.TYPE_HINTS,
+    query_type4py: bool = False,
 ) -> ModuleTestCluster:
     """Analyses a module to build a test cluster.
 
     Args:
         parsed_module: The parsed module
         type_inference_strategy: The type inference strategy to use.
+        query_type4py: Query Type4Py for types.
 
     Returns:
         A test cluster for the module
@@ -1283,6 +1402,7 @@ def analyse_module(
         root_module=parsed_module,
         type_inference_strategy=type_inference_strategy,
         test_cluster=test_cluster,
+        query_type4py=query_type4py,
     )
     return test_cluster
 
@@ -1290,14 +1410,20 @@ def analyse_module(
 def generate_test_cluster(
     module_name: str,
     type_inference_strategy: TypeInferenceStrategy = TypeInferenceStrategy.TYPE_HINTS,
+    query_type4py: bool = False,
 ) -> ModuleTestCluster:
     """Generates a new test cluster from the given module.
 
     Args:
-        module_name: The name of the module
+        module_name: The name of the root module
         type_inference_strategy: Which type-inference strategy to use
+        query_type4py: Query Type4Py for types.
 
     Returns:
         A new test cluster for the given module
     """
-    return analyse_module(parse_module(module_name), type_inference_strategy)
+    return analyse_module(
+        parse_module(module_name, query_type4py=query_type4py),
+        type_inference_strategy,
+        query_type4py=query_type4py,
+    )
