@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -95,7 +95,7 @@ class TypeNameAssertion(ReferenceAssertion):
 
     @property
     def module(self) -> str:
-        """Provides the module name
+        """Provides the module name.
 
         Returns:
             The module name
@@ -104,7 +104,7 @@ class TypeNameAssertion(ReferenceAssertion):
 
     @property
     def qualname(self) -> str:
-        """Provides the qualname name
+        """Provides the qualname name.
 
         Returns:
             The qualname
