@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -124,6 +124,7 @@ def _setup_logging(
     if no_rich:
         handler: logging.Handler = logging.StreamHandler()
     else:
+        install()
         console = Console(tab_size=4)
         handler = RichHandler(
             rich_tracebacks=True, log_time_format="[%X]", console=console
@@ -144,7 +145,7 @@ def _setup_logging(
 _DANGER_ENV = "PYNGUIN_DANGER_AWARE"
 
 
-def main(argv: list[str] = None) -> int:
+def main(argv: list[str] | None = None) -> int:
     """Entry point for the CLI of the Pynguin automatic unit test generation framework.
 
     This method behaves like a standard UNIX command-line application, i.e.,
@@ -160,8 +161,7 @@ def main(argv: list[str] = None) -> int:
         success, all non-zero exit codes indicate errors.
     """
     if _DANGER_ENV not in os.environ:
-        # pylint: disable=print-function
-        print(
+        print(  # noqa: T201
             f"""Environment variable '{_DANGER_ENV}' not set.
 Aborting to avoid harming your system.
 Please refer to the documentation
@@ -170,7 +170,6 @@ to see why this happens and what you must do to prevent it."""
         )
         return -1
 
-    install()
     if argv is None:
         argv = sys.argv
     if len(argv) <= 1:
