@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -59,7 +59,7 @@ class SelectionFunction(Generic[T]):
 
     @maximize.setter
     def maximize(self, new_value: bool) -> None:
-        """Sets whether this is a maximising fitness function
+        """Sets whether this is a maximising fitness function.
 
         Args:
             new_value: The new value
