@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -30,7 +30,7 @@ class TestSuiteChromosomeFactory(
         fitness_functions: OrderedSet[ff.TestSuiteFitnessFunction],
         coverage_functions: OrderedSet[ff.TestSuiteCoverageFunction],
     ):
-        """Instantiates a new factory
+        """Instantiates a new factory.
 
         Args:
             test_case_chromosome_factory: The internal test case chromosome factory,
