@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -208,7 +208,8 @@ class MIOPopulation:
     @property
     def counter(self) -> int:
         """How often was a solution sampled from this population since the last
-        improvement in the h-value."""
+        improvement in the h-value.
+        """
         return self._counter
 
     @property
@@ -381,7 +382,6 @@ class MIOArchive(Archive):
 
     def get_solution(self) -> tcc.TestCaseChromosome | None:
         """Get a random solution."""
-
         # Choose one target at random that has not been covered but contains some
         # solutions. In case there is not any non-covered target with at least one
         # solution, either because all targets have been covered or for the non-covered
