@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -214,7 +214,7 @@ class TestSuiteGenerationAlgorithmFactory(
         """
         strategy = self._get_generation_strategy()
         strategy.branch_goal_pool = bg.BranchGoalPool(
-            self._executor.tracer.get_known_data()
+            self._executor.tracer.get_subject_properties()
         )
         strategy.test_case_fitness_functions = self._get_test_case_fitness_functions(
             strategy
@@ -407,7 +407,7 @@ class TestSuiteGenerationAlgorithmFactory(
             return FilteredModuleTestCluster(
                 self._test_cluster,
                 strategy.archive,
-                self._executor.tracer.get_known_data(),
+                self._executor.tracer.get_subject_properties(),
                 strategy.test_case_fitness_functions,
             )
         return self._test_cluster
