@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -50,7 +50,7 @@ class StoppingCondition(so.SearchObserver, ExecutionObserver, metaclass=ABCMeta)
 
     @abstractmethod
     def is_fulfilled(self) -> bool:
-        """Returns whether the condition is fulfilled, thus the algorithm should stop
+        """Returns whether the condition is fulfilled, thus the algorithm should stop.
 
         Returns:
             True if the condition is fulfilled, False otherwise  # noqa: DAR202
