@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -21,6 +21,7 @@ from __future__ import annotations
 import datetime
 import enum
 import importlib
+import json
 import logging
 import os
 import sys
@@ -117,6 +118,7 @@ def _setup_test_cluster() -> ModuleTestCluster | None:
     test_cluster = generate_test_cluster(
         config.configuration.module_name,
         config.configuration.type_inference.type_inference_strategy,
+        query_type4py=config.configuration.type_inference.type4py,
     )
     if test_cluster.num_accessible_objects_under_test() == 0:
         _LOGGER.error("SUT contains nothing we can test.")
@@ -242,7 +244,6 @@ def _setup_and_check() -> tuple[
     Returns:
         An optional tuple of test-case executor and test cluster
     """
-
     if not _setup_path():
         return None
     wrapped_constant_provider, dynamic_constant_provider = _setup_constant_seeding()
@@ -282,15 +283,22 @@ def _track_sut_data(tracer: ExecutionTracer, test_cluster: ModuleTestCluster) ->
     """
     stat.track_output_variable(
         RuntimeVariable.CodeObjects,
-        len(tracer.get_known_data().existing_code_objects),
+        len(tracer.get_subject_properties().existing_code_objects),
     )
     stat.track_output_variable(
         RuntimeVariable.Predicates,
-        len(tracer.get_known_data().existing_predicates),
+        len(tracer.get_subject_properties().existing_predicates),
     )
     stat.track_output_variable(
         RuntimeVariable.Lines,
-        len(tracer.get_known_data().existing_lines),
+        len(tracer.get_subject_properties().existing_lines),
+    )
+    cyclomatic_complexities: list[int] = [
+        code.original_cfg.cyclomatic_complexity
+        for code in tracer.get_subject_properties().existing_code_objects.values()
+    ]
+    stat.track_output_variable(
+        RuntimeVariable.McCabeCodeObject, json.dumps(cyclomatic_complexities)
     )
     test_cluster.track_statistics_values(stat.track_output_variable)
     if (
@@ -299,7 +307,9 @@ def _track_sut_data(tracer: ExecutionTracer, test_cluster: ModuleTestCluster) ->
     ):
         stat.track_output_variable(
             RuntimeVariable.ImportBranchCoverage,
-            ff.compute_branch_coverage(tracer.import_trace, tracer.get_known_data()),
+            ff.compute_branch_coverage(
+                tracer.import_trace, tracer.get_subject_properties()
+            ),
         )
     if (
         config.CoverageMetric.LINE
@@ -307,7 +317,9 @@ def _track_sut_data(tracer: ExecutionTracer, test_cluster: ModuleTestCluster) ->
     ):
         stat.track_output_variable(
             RuntimeVariable.ImportLineCoverage,
-            ff.compute_line_coverage(tracer.import_trace, tracer.get_known_data()),
+            ff.compute_line_coverage(
+                tracer.import_trace, tracer.get_subject_properties()
+            ),
         )
 
 
@@ -341,11 +353,13 @@ def _reload_instrumentation_loader(
     module_name = config.configuration.module_name
     module = importlib.import_module(module_name)
     tracer.current_thread_identifier = threading.current_thread().ident
-    first_finder = sys.meta_path[0]
-    assert isinstance(first_finder, InstrumentationFinder)
-    finder: InstrumentationFinder = first_finder
-    # pylint:disable=no-member
-    finder.update_instrumentation_metrics(
+    first_finder: InstrumentationFinder | None = None
+    for finder in sys.meta_path:
+        if isinstance(finder, InstrumentationFinder):
+            first_finder = finder
+            break
+    assert first_finder is not None
+    first_finder.update_instrumentation_metrics(
         tracer=tracer,
         coverage_metrics=coverage_metrics,
         dynamic_constant_provider=dynamic_constant_provider,
@@ -548,13 +562,12 @@ def _run() -> ReturnCode:
             Path(config.configuration.statistics_output.report_dir) / "cov_report.xml",
             datetime.datetime.now(),
         )
-    _collect_miscellaneous_statistics()
+    _collect_miscellaneous_statistics(test_cluster)
     if not stat.write_statistics():
         _LOGGER.error("Failed to write statistics data")
     if generation_result.size() == 0:
         # not able to generate one test case
         return ReturnCode.NO_TESTS_GENERATED
-    test_cluster.log_signatures()
     return ReturnCode.OK
 
 
@@ -649,7 +662,8 @@ def _instantiate_test_generation_strategy(
     return factory.get_search_algorithm()
 
 
-def _collect_miscellaneous_statistics() -> None:
+def _collect_miscellaneous_statistics(test_cluster) -> None:
+    test_cluster.log_cluster_statistics()
     stat.track_output_variable(
         RuntimeVariable.TargetModule, config.configuration.module_name
     )
@@ -658,6 +672,9 @@ def _collect_miscellaneous_statistics() -> None:
         RuntimeVariable.ConfigurationId,
         config.configuration.statistics_output.configuration_id,
     )
+    stat.track_output_variable(
+        RuntimeVariable.RunId, config.configuration.statistics_output.run_id
+    )
     stat.track_output_variable(
         RuntimeVariable.ProjectName, config.configuration.statistics_output.project_name
     )
@@ -675,6 +692,7 @@ def _export_chromosome(
         chromosome: the chromosome to export.
         file_name_suffix: Suffix that can be added to the file name to distinguish
             between different results e.g., failing and succeeding test cases.
+
     Returns:
         The name of the target file
     """
