@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -41,13 +41,18 @@ if TYPE_CHECKING:
     from pynguin.instrumentation.instrumentation import CodeObjectMetaData
     from pynguin.slicer.executedinstruction import ExecutedInstruction
     from pynguin.slicer.executionflowbuilder import LastInstrState
-    from pynguin.testcase.execution import ExecutedAssertion, ExecutionTrace, KnownData
+    from pynguin.testcase.execution import (
+        ExecutedAssertion,
+        ExecutionTrace,
+        SubjectProperties,
+    )
 
 
 @dataclass
 class SlicingCriterion:
     """Slicing criterion data class holding the instruction
-    and position in the trace to slice for."""
+    and position in the trace to slice for.
+    """
 
     unique_instr: UniqueInstruction
     trace_position: int
@@ -56,7 +61,8 @@ class SlicingCriterion:
 @dataclass
 class SlicingContext:  # pylint: disable=too-many-instance-attributes
     """Data class storing all defined and used variables as well as instructions
-    used at one point during the slicing."""
+    used at one point during the slicing.
+    """
 
     # Instructions included in the slice
     instr_in_slice: list[UniqueInstruction] = field(default_factory=list)
@@ -82,7 +88,8 @@ class SlicingContext:  # pylint: disable=too-many-instance-attributes
 @dataclass
 class SlicingState:  # pylint: disable=too-many-instance-attributes
     """Holds the configuration and state of the dynamic slicing process
-    for each analysed instruction."""
+    for each analysed instruction.
+    """
 
     basic_block_id: int
     code_object_id: int
@@ -533,7 +540,6 @@ class DynamicSlicer:
             A tuple with either False and an empty set or True and a set containing all
             explicit attribute creation uses.
         """
-
         complete_cover = False
         partial_cover = False
         attribute_creation_uses = set()
@@ -769,13 +775,13 @@ class DynamicSlicer:
 
     @staticmethod
     def get_line_id_by_instruction(
-        instruction: UniqueInstruction, known_data: KnownData
+        instruction: UniqueInstruction, subject_properties: SubjectProperties
     ) -> int:
         """Get the line id of the line an instruction belongs to.
 
         Args:
             instruction: the instruction the line id is needed for
-            known_data: the known data about the module under test
+            subject_properties: the known data about the module under test
 
         Returns:
             the line id used by the line of an instruction
@@ -783,7 +789,7 @@ class DynamicSlicer:
         Raises:
             ValueError: If the line of the instruction is not part of the known data.
         """
-        for (line_id, line_meta) in known_data.existing_lines.items():
+        for (line_id, line_meta) in subject_properties.existing_lines.items():
             if (
                 line_meta.file_name == instruction.file
                 and line_meta.line_number == instruction.lineno
@@ -793,14 +799,14 @@ class DynamicSlicer:
 
     @staticmethod
     def map_instructions_to_lines(
-        instructions: list[UniqueInstruction], known_data: KnownData
+        instructions: list[UniqueInstruction], subject_properties: SubjectProperties
     ) -> set[int]:
         """Map the list of instructions in a slice to a set of lines of the module
         under test. Instructions of the test case statements are ignored.
 
         Args:
             instructions: list of unique instructions
-            known_data: the known data about the module under test
+            subject_properties: the known data about the module under test
 
         Returns:
             a set of line ids used in the given list of instructions
@@ -814,7 +820,9 @@ class DynamicSlicer:
                 continue
             curr_line = instruction.lineno
             line_ids.add(
-                DynamicSlicer.get_line_id_by_instruction(instruction, known_data)
+                DynamicSlicer.get_line_id_by_instruction(
+                    instruction, subject_properties
+                )
             )
         return line_ids
 
@@ -822,7 +830,8 @@ class DynamicSlicer:
 # pylint:disable=too-few-public-methods
 class AssertionSlicer:
     """Holds all logic of slicing traced assertions to generate the
-    dynamic slice produced by a test."""
+    dynamic slice produced by a test.
+    """
 
     def __init__(
         self,
@@ -868,7 +877,7 @@ class AssertionSlicer:
     def slice_assertion(
         self, assertion: ExecutedAssertion, trace: ExecutionTrace
     ) -> list[UniqueInstruction]:
-        """Calculate the dynamic slice for an assertion inside a test case
+        """Calculate the dynamic slice for an assertion inside a test case.
 
         Args:
             assertion: The assertion, for which to calculate the slice.
@@ -877,7 +886,6 @@ class AssertionSlicer:
         Returns:
             The list of executed instructions contained in the slice of the assertion.
         """
-
         slicing_criterion = self._slicing_criterion_from_assertion(assertion, trace)
         slicer = DynamicSlicer(self._known_code_objects)
         return slicer.slice(trace, slicing_criterion)
