@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -42,7 +42,7 @@ class UniqueInstruction(Instr):
         code_meta: CodeObjectMetaData,
         offset: int,
         arg=UNSET,
-        lineno: int = None,
+        lineno: int | None = None,
         in_slice: bool = False,
     ):
         self.file = file
@@ -74,7 +74,7 @@ class UniqueInstruction(Instr):
 
     @in_slice.setter
     def in_slice(self, in_slice) -> None:
-        """Sets whether the instruction is inside the slice
+        """Sets whether the instruction is inside the slice.
 
         Args:
             in_slice: whether the instruction is inside the slice
@@ -164,7 +164,8 @@ class LastInstrState:  # pylint: disable=too-many-instance-attributes
 @dataclass
 class ExecutionFlowBuilderState:  # pylint: disable=too-many-instance-attributes
     """Holds the configuration and state of the execution flow builder
-    while determining the last instruction executed."""
+    while determining the last instruction executed.
+    """
 
     bb_id: int
     co_id: int
