@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -19,10 +19,12 @@ import pynguin.testcase.variablereference as vr
 import pynguin.utils.generic.genericaccessibleobject as gao
 from pynguin.analyses import constants
 from pynguin.analyses.typesystem import (
+    ANY,
     InferredSignature,
     Instance,
     NoneType,
     ProperType,
+    TypeInfo,
 )
 from pynguin.utils import randomness
 from pynguin.utils.mutation_utils import alpha_exponent_insertion
@@ -297,6 +299,14 @@ class StatementVisitor(metaclass=ABCMeta):
             stmt: the statement to visit
         """
 
+    @abstractmethod
+    def visit_class_primitive_statement(self, stmt) -> None:
+        """Visit class primitive statement.
+
+        Args:
+            stmt: the statement to visit
+        """
+
     @abstractmethod
     def visit_none_statement(self, stmt) -> None:
         """Visit none.
@@ -384,7 +394,8 @@ class AssignmentStatement(Statement):
     possibly nested fields.
 
     For example:
-        foo_0.baz = int_0"""
+    foo_0.baz = int_0
+    """
 
     def __init__(
         self,
@@ -568,7 +579,8 @@ class CollectionStatement(Generic[T], VariableCreatingStatement):
 class NonDictCollection(CollectionStatement[vr.VariableReference], metaclass=ABCMeta):
     """Abstract base class for collections that are not dicts.
     We have to handle dicts in a special way, because mutation can affect either
-    the key or the value of an item."""
+    the key or the value of an item.
+    """
 
     def _insertion_supplier(self) -> vr.VariableReference | None:
         arg_type = cast(Instance, self.ret_val.type).args[0]
@@ -1232,7 +1244,13 @@ class MethodStatement(ParametrizedStatement):
         # We mutate the callee here, as the special parameter.
         if randomness.next_float() < p_per_param:
             callee = self.callee
-            objects = self.test_case.get_objects(callee.type, self.get_position())
+            typ = (
+                ANY
+                if randomness.next_float()
+                < config.configuration.test_creation.use_random_object_for_call
+                else callee.type
+            )
+            objects = self.test_case.get_objects(typ, self.get_position())
             if callee in objects:
                 objects.remove(callee)
 
@@ -1865,7 +1883,8 @@ class BooleanPrimitiveStatement(PrimitiveStatement[bool]):
 
 class EnumPrimitiveStatement(PrimitiveStatement[int]):
     """Primitive Statement that references the value of an enum.
-    We simply store the index of the element in the Enum."""
+    We simply store the index of the element in the Enum.
+    """
 
     def __init__(
         self,
@@ -1885,7 +1904,8 @@ class EnumPrimitiveStatement(PrimitiveStatement[int]):
         the stored index.
 
         Returns:
-            The associated enum value."""
+            The associated enum value.
+        """
         assert self._value is not None
         return self._generic_enum.names[self._value]
 
@@ -1930,6 +1950,67 @@ class EnumPrimitiveStatement(PrimitiveStatement[int]):
         visitor.visit_enum_statement(self)
 
 
+class ClassPrimitiveStatement(PrimitiveStatement[int]):
+    """Primitive Statement that references a class."""
+
+    def __init__(self, test_case: tc.TestCase, value: int | None = None):
+        # TODO(fk) think about type being generic/bound, e.g., type[Foo]
+        # We store the index in the global class list here.
+        super().__init__(
+            test_case,
+            Instance(test_case.test_cluster.type_system.to_type_info(type)),
+            value,
+        )
+
+    @property
+    def type_info(self) -> TypeInfo:
+        """Convenience method to access the type that is associated with
+        the stored index.
+
+        Returns:
+            The associated type info.
+        """
+        assert self._value is not None
+        return self._test_case.test_cluster.type_system.get_all_types()[self._value]
+
+    def randomize_value(self) -> None:
+        self._value = randomness.next_int(
+            0, len(self._test_case.test_cluster.type_system.get_all_types())
+        )
+
+    def delta(self) -> None:
+        assert self._value is not None
+        num_classes = len(self._test_case.test_cluster.type_system.get_all_types())
+        self._value += randomness.choice([-1, 1])
+        self._value = (self._value + num_classes) % num_classes
+
+    def clone(
+        self,
+        test_case: tc.TestCase,
+        memo: dict[vr.VariableReference, vr.VariableReference],
+    ) -> ClassPrimitiveStatement:
+        return ClassPrimitiveStatement(test_case, value=self.value)
+
+    def __repr__(self) -> str:
+        return f"EnumPrimitiveStatement({self._test_case}, {self._value})"
+
+    def __str__(self) -> str:
+        assert self._value is not None
+        return f"{self.type_info.full_name}: type"
+
+    def structural_eq(
+        self,
+        other: Statement,
+        memo: dict[vr.VariableReference, vr.VariableReference],
+    ) -> bool:
+        return super().structural_eq(other, memo) and isinstance(
+            other, ClassPrimitiveStatement
+        )
+
+    def accept(self, visitor: StatementVisitor) -> None:
+        visitor.visit_class_primitive_statement(self)
+
+
 class NoneStatement(PrimitiveStatement[None]):
     """A statement serving as a None reference."""
 
