@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -15,6 +15,7 @@ import pynguin.testcase.statement as stmt
 import pynguin.utils.generic.genericaccessibleobject as gao
 from pynguin.analyses.constants import ConstantProvider, EmptyConstantProvider
 from pynguin.analyses.typesystem import (
+    ANY,
     InferredSignature,
     Instance,
     NoneType,
@@ -538,7 +539,13 @@ class TestFactory:
             Whether the insertion was successful
         """
         try:
-            accessible = self._test_cluster.get_random_call_for(variable.type)
+            typ = (
+                ANY
+                if randomness.next_float()
+                < config.configuration.test_creation.use_random_object_for_call
+                else variable.type
+            )
+            accessible = self._test_cluster.get_random_call_for(typ)
             return self.add_call_for(test_case, variable, accessible, position)
         except ConstructionFailedException:
             pass
@@ -667,7 +674,13 @@ class TestFactory:
         changed = False
         if variable is not None:
             for i in range(position + 1, test_case.size()):
-                alternatives = test_case.get_objects(variable.type, i)
+                typ = (
+                    ANY
+                    if randomness.next_float()
+                    < config.configuration.test_creation.use_random_object_for_call
+                    else variable.type
+                )
+                alternatives = test_case.get_objects(typ, i)
                 try:
                     alternatives.remove(variable)
                 except ValueError:
@@ -1084,6 +1097,7 @@ class TestFactory:
 
         if isinstance(parameter_type, NoneType):
             return self._create_none(test_case, position, recursion_depth)
+        # TODO(fk) think about creating collections/primitives from calls?
         if parameter_type.accept(is_primitive_type):
             return self._create_primitive(
                 test_case,
@@ -1169,6 +1183,8 @@ class TestFactory:
                 statement = stmt.StringPrimitiveStatement(
                     test_case, constant_provider=constant_provider
                 )
+            case "type":
+                statement = stmt.ClassPrimitiveStatement(test_case)
             case _:
                 raise RuntimeError(f"Unknown primitive {parameter_type}")
         ret = test_case.add_variable_creating_statement(statement, position)
