@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -24,6 +24,7 @@ if typing.TYPE_CHECKING:
         ProperType,
         TupleType,
         UnionType,
+        Unsupported,
     )
 
 
@@ -58,7 +59,7 @@ class AbstractNamingScope:
 
     @abstractmethod
     def __iter__(self):
-        """Iterate the objects and the associated names"""
+        """Iterate the objects and the associated names."""
 
 
 class NamingScope(AbstractNamingScope):
@@ -169,6 +170,9 @@ class _VariableNameTypeVisitor(TypeVisitor[str]):
     def visit_union_type(self, left: UnionType) -> str:
         return self._prefix
 
+    def visit_unsupported_type(self, left: Unsupported) -> str:
+        raise NotImplementedError("This type shall not be used during runtime")
+
 
 def snake_case(name: str) -> str:
     """Create a snake case representation from the given string.
