@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -70,8 +70,8 @@ class CSVStatisticsBackend(AbstractStatisticsBackend):
 
 # pylint: disable=too-few-public-methods
 class ConsoleStatisticsBackend(AbstractStatisticsBackend):
-    """Simple dummy backend that just outputs all output variables to the console"""
+    """Simple dummy backend that just outputs all output variables to the console."""
 
     def write_data(self, data: dict[str, OutputVariable]) -> None:
         for key, value in data.items():
-            print(f"{key}: {value}")  # pylint:disable=print-function
+            print(f"{key}: {value}")  # noqa: T201
