@@ -1,6 +1,6 @@
 #  This file is part of Pynguin.
 #
-#  SPDX-FileCopyrightText: 2019–2022 Pynguin Contributors
+#  SPDX-FileCopyrightText: 2019–2023 Pynguin Contributors
 #
 #  SPDX-License-Identifier: LGPL-3.0-or-later
 #
@@ -31,9 +31,12 @@ from pynguin.utils.orderedset import OrderedSet
 
 LOGGER = logging.getLogger(__name__)
 
+# Max depth for proxies. Afterwards we don't wrap values anymore.
+_MAX_PROXY_NESTING = 5
+
 
 @dataclasses.dataclass
-class ProxyKnowledge:
+class UsageTraceNode:
     """The knowledge gathered by a proxy."""
 
     name: str
@@ -42,8 +45,8 @@ class ProxyKnowledge:
     # Zero indicates that it is the root.
     depth: int = 0
 
-    # Symbols that have been accessed on this proxy.
-    symbol_table: dict[str, ProxyKnowledge] = dataclasses.field(init=False)
+    # Attributes that have been accessed on this proxy.
+    children: dict[str, UsageTraceNode] = dataclasses.field(init=False)
 
     # The type against which this proxy was checked.
     type_checks: OrderedSet[type] = dataclasses.field(default_factory=OrderedSet)
@@ -54,7 +57,25 @@ class ProxyKnowledge:
     )
 
     def __post_init__(self):
-        self.symbol_table = DepthDefaultDict(self.depth)
+        self.children = DepthDefaultDict(self.depth)
+
+    def find_path(self, path: tuple[str, ...]) -> UsageTraceNode | None:
+        """Check if this usage trace tree has the given path.
+
+        Args:
+            path: The path to check
+
+        Returns:
+            The usage trace node at the end of the path, if it exists, otherwise None.
+        """
+        assert len(path) > 0, "Expected non-empty path."
+        current = self
+        for element in path:
+            if element in current.children:
+                current = current.children[element]
+            else:
+                return None
+        return current
 
     def pretty(self) -> str:
         """Create a pretty representation of this object.
@@ -67,17 +88,20 @@ class ProxyKnowledge:
         )
         return tree({self._format_str(): self._format_children()})
 
+    def __len__(self):
+        return len(self.children) + len(self.arg_types) + len(self.type_checks)
+
     def _format_str(self):
         output = f"'{self.name}'"
         if len(self.type_checks) > 0:
             output += (
-                " (type-checks: {"
+                ", type_checks: {"
                 + ", ".join([check.__name__ for check in self.type_checks])
-                + "})"
+                + "}"
             )
         if len(self.arg_types) > 0:
             output += (
-                " (arg-types: {"
+                ", arg_types: {"
                 + ", ".join(
                     [
                         str(idx)
@@ -87,18 +111,18 @@ class ProxyKnowledge:
                         for idx, types in self.arg_types.items()
                     ]
                 )
-                + "})"
+                + "}"
             )
         return output
 
     def _format_children(self):
         return {
             child._format_str(): child._format_children()
-            for child in self.symbol_table.values()
+            for child in self.children.values()
         }
 
     @staticmethod
-    def from_proxy(obj: ObjectProxy) -> ProxyKnowledge:
+    def from_proxy(obj: ObjectProxy) -> UsageTraceNode:
         """Extract knowledge from the given proxy.
         This is a convenience method, because the knowledge attribute is not visible
         on a proxy.
@@ -109,9 +133,9 @@ class ProxyKnowledge:
         Returns:
             The extracted knowledge.
         """
-        return obj._self_proxy_knowledge
+        return obj._self_usage_trace_node
 
-    def merge(self, other: ProxyKnowledge) -> None:
+    def merge(self, other: UsageTraceNode) -> None:
         """Merge the knowledge from the other proxy into this one.
 
         Args:
@@ -121,21 +145,22 @@ class ProxyKnowledge:
         assert self.depth == other.depth
         self.arg_types.update(other.arg_types)
         self.type_checks.update(other.type_checks)
-        for symbol, knowledge in other.symbol_table.items():
-            self.symbol_table[symbol].merge(knowledge)
+        for attr, knowledge in other.children.items():
+            self.children[attr].merge(knowledge)
 
 
-class DepthDefaultDict(dict[str, ProxyKnowledge]):
-    """Default dict which automatically creates a ProxyKnowledge for each requested
-    and non-existing key."""
+class DepthDefaultDict(dict[str, UsageTraceNode]):
+    """Default dict which automatically creates a UsageTraceNode for each requested
+    and non-existing key.
+    """
 
     def __init__(self, depth: int):
         super().__init__()
         self._depth = depth
 
     def __missing__(self, key):
-        # Create knowledge for missing symbol
-        res = self[key] = ProxyKnowledge(key, depth=self._depth + 1)
+        # Create knowledge for missing attribute
+        res = self[key] = UsageTraceNode(key, depth=self._depth + 1)
         return res
 
 
@@ -154,8 +179,8 @@ def proxify(log_arg_types=False, no_wrap_return=False):
     def wrap(function):
         def wrapped(*args, **kwargs):
             self = args[0]
-            knowledge = ProxyKnowledge.from_proxy(self)
-            nested_knowledge = knowledge.symbol_table[function.__name__]
+            knowledge = UsageTraceNode.from_proxy(self)
+            nested_knowledge = knowledge.children[function.__name__]
             if len(args) > 1:
                 if any(isinstance(arg, ObjectProxy) for arg in args[1:]):
                     # Only record access but nothing more, if we interact with another
@@ -164,9 +189,9 @@ def proxify(log_arg_types=False, no_wrap_return=False):
                 if log_arg_types:
                     for pos, arg in enumerate(args[1:]):
                         nested_knowledge.arg_types[pos].add(type(arg))
-            if no_wrap_return:
+            if no_wrap_return or knowledge.depth >= _MAX_PROXY_NESTING:
                 return function(*args, **kwargs)
-            return ObjectProxy(function(*args, **kwargs), knowledge=nested_knowledge)
+            return ObjectProxy(function(*args, **kwargs), usage_trace=nested_knowledge)
 
         return wrapped
 
@@ -184,7 +209,7 @@ class _ObjectProxyMethods:
     # via a meta class. In that way the properties will always take
     # precedence.
 
-    @property  # type:ignore
+    @property
     def __module__(self):
         return self.__wrapped__.__module__  # type:ignore # pylint:disable=no-member
 
@@ -192,7 +217,7 @@ class _ObjectProxyMethods:
     def __module__(self, value):
         self.__wrapped__.__module__ = value  # type:ignore # pylint:disable=no-member
 
-    @property  # type:ignore
+    @property
     def __doc__(self):
         return self.__wrapped__.__doc__  # type:ignore # pylint:disable=no-member
 
@@ -246,17 +271,21 @@ def unwrap(obj):
 class ObjectProxy(metaclass=_ObjectProxyMetaType):
     """A proxy for (almost) any Python object.
 
-    Native types implemented in C might be problematic."""
+    Native types implemented in C might be problematic.
+    """
 
     def __init__(
-        self, wrapped, knowledge: ProxyKnowledge | None = None, is_kwargs: bool = False
+        self,
+        wrapped,
+        usage_trace: UsageTraceNode | None = None,
+        is_kwargs: bool = False,
     ):
         object.__setattr__(self, "__wrapped__", wrapped)
         # What does this proxy know?
         object.__setattr__(
             self,
-            "_self_proxy_knowledge",
-            ProxyKnowledge(name="ROOT") if knowledge is None else knowledge,
+            "_self_usage_trace_node",
+            UsageTraceNode(name="ROOT") if usage_trace is None else usage_trace,
         )
         # Is this proxy passed as **kwargs? If so, we can't return proxies from 'keys'
         # but must return the raw string objects.
@@ -388,10 +417,10 @@ class ObjectProxy(metaclass=_ObjectProxyMetaType):
             object.__setattr__(self, name, value)
 
         else:
-            knowledge = ProxyKnowledge.from_proxy(self)
-            accessed = knowledge.symbol_table[name]
-            # Knowledge is created implicitly.
-            assert accessed
+            node = UsageTraceNode.from_proxy(self)
+            accessed = node.children[name]
+            # Node is created implicitly.
+            assert accessed is not None
             setattr(self.__wrapped__, name, value)  # type:ignore
 
     def __getattr__(self, name):
@@ -406,13 +435,15 @@ class ObjectProxy(metaclass=_ObjectProxyMetaType):
             # dict for **kwargs
             return getattr(self.__wrapped__, name)  # type:ignore
 
-        knowledge = self._self_proxy_knowledge
+        node = self._self_usage_trace_node
         # Done before getattr, to make sure we store the access in case of an
         # exception
-        child_knowledge = knowledge.symbol_table[name]
+        child_node = node.children[name]
+        if node.depth >= _MAX_PROXY_NESTING:
+            return getattr(self.__wrapped__, name)  # type:ignore
         return ObjectProxy(
             getattr(self.__wrapped__, name),  # type:ignore
-            knowledge=child_knowledge,
+            usage_trace=child_node,
         )
 
     def __delattr__(self, name):
@@ -657,11 +688,14 @@ class ObjectProxy(metaclass=_ObjectProxyMetaType):
         return self.__wrapped__.__exit__(*args, **kwargs)
 
     def __iter__(self):
-        knowledge = self._self_proxy_knowledge
-        nested_knowledge = knowledge.symbol_table["__iter__"]
-        for i in self.__wrapped__:
-            proxy = ObjectProxy(i, knowledge=nested_knowledge)
-            yield proxy
+        node = self._self_usage_trace_node
+        nested_node = node.children["__iter__"]
+        if node.depth >= _MAX_PROXY_NESTING:
+            yield from self.__wrapped__
+        else:
+            for i in self.__wrapped__:
+                proxy = ObjectProxy(i, usage_trace=nested_node)
+                yield proxy
 
     # These do not give us any hint.
     # def __copy__(self):
@@ -678,7 +712,7 @@ class ObjectProxy(metaclass=_ObjectProxyMetaType):
     #     raise NotImplementedError(
     #             'object proxy must define __reduce_ex__()')
 
-    @proxify()
+    @proxify(log_arg_types=True)
     def __call__(self, *args, **kwargs):
         return self.__wrapped__(*args, **kwargs)
 
@@ -686,7 +720,7 @@ class ObjectProxy(metaclass=_ObjectProxyMetaType):
 @contextlib.contextmanager
 def shim_isinstance():
     """Context manager that temporarily replaces isinstance with a shim.
-    The shim is aware of ObjectProxies
+    The shim is aware of ObjectProxies.
 
     Yields:
         resets the shim
@@ -695,12 +729,18 @@ def shim_isinstance():
 
     def shim(inst, types):
         # pylint:disable=unidiomatic-typecheck
-        if type(inst) is ObjectProxy and not orig_isinstance(types, ObjectProxy):
+        if type(inst) is ObjectProxy:
+            if types is ObjectProxy or orig_isinstance(types, ObjectProxy):
+                return orig_isinstance(inst, types)
             if orig_isinstance(types, tuple):
-                if ObjectProxy not in types:
-                    ProxyKnowledge.from_proxy(inst).type_checks.update(types)
-            elif types is not ObjectProxy:
-                ProxyKnowledge.from_proxy(inst).type_checks.add(types)
+                if any(
+                    typ is ObjectProxy or orig_isinstance(typ, ObjectProxy)
+                    for typ in types
+                ):
+                    return orig_isinstance(inst, types)
+                UsageTraceNode.from_proxy(inst).type_checks.update(types)
+            else:
+                UsageTraceNode.from_proxy(inst).type_checks.add(types)
         return orig_isinstance(inst, types)
 
     builtins.isinstance = shim
